{ config, lib, pkgs, ... }:

{
  # Display manager
  services.xserver.enable = true;
  services.xserver.displayManager = {
    defaultSession = "sway";
    sddm = {
      enable = true;
      autoLogin = {
        enable = true;
        user = "coolneng";
      };
    };
  };

  # Window manager
  programs.sway = {
    enable = true;
    extraPackages = with pkgs; [
      xwayland
      swaylock
      swaybg
      rofi
      waybar
      clipman
      grim
      slurp
      brillo
      imv
      kanshi
      redshift-wlr
      kitty
    ];
    extraSessionCommands = ''
      export MOZ_ENABLE_WAYLAND=1
      export MOZ_DBUS_REMOTE=1
      export GRIM_DEFAULT_DIR=/home/coolneng/Photos/Screenshots
      export _JAVA_AWT_WM_NONREPARENTING=1
      export QT_QPA_PLATFORM=wayland
      export QT_WAYLAND_DISABLE_WINDOWDECORATION="1"
      export SDL_VIDEODRIVER=wayland
    '';
  };
  wayland.windowManager.sway = {
    enable = true;
    config = {
      input = { * = {xkb_layout = "es"}; };
      menu = "rofi -show drun";
      terminal = "kitty";
      keybindings = lib.mkOptionDefault {
        "${modifier}+Return" = "exec ${terminal}";
        "${modifier}+w" = "kill";
        "${modifier}+d" = "exec ${menu}";
      };
      startup = [
        {command = "kitty --class tmux -- tmuxp load ~/.tmuxp/local.yaml"; workspace = "1";} 
        {command = "firefox"; workspace = "2";} 
        {command = "emacs"; workspace = "3";} 
      ];
      window.commands = [
        {command = "floating enable"; criteria = {class = "mpv";} ; }
        {command = "floating enable"; criteria = {class = "imv";} ; }
      ];
      workspaceAutoBackAndForth = true;
    };
    extraSessionCommands = ''
      export MOZ_ENABLE_WAYLAND=1
      export MOZ_DBUS_REMOTE=1
      export GRIM_DEFAULT_DIR=/home/coolneng/Photos/Screenshots
      export _JAVA_AWT_WM_NONREPARENTING=1
      export QT_QPA_PLATFORM=wayland
      export QT_WAYLAND_DISABLE_WINDOWDECORATION="1"
      export SDL_VIDEODRIVER=wayland
    '';
  };
   
  # Blue light filter
  services.redshift = {
    package = pkgs.redshift-wlr;
    enable = true;
    temperature = {
      day = 6500;
      night = 5000;
    };
  };
  location = {
    latitude = 35.89;
    longitude = -5.32;
  };

  # Bar
  programs.waybar.enable = true;
}
